@@ -163,10 +163,7 @@ notation_data(int len)
 	vlen = Getc() * 256;
 	vlen += Getc();
 	printf("\t\tName - ");
-	if (human)
-		pdump(nlen);
-	else
-		dump(nlen);
+	pdump(nlen);
 	printf("\n");
 	printf("\t\tValue - ");
 	if (human)
@@ -281,7 +278,7 @@ reason_for_revocation(int len)
 		printf("No reason specified");
 		break;
 	case 1:
-		printf("Key is superceded");
+		printf("Key is superseded");
 		break;
 	case 2:
 		printf("Key material has been compromised");
@@ -307,9 +304,9 @@ features(int len)
 {
         int c = Getc();
         if (c & 0x01)
-                printf("\t\tFlag - Modification detection (packets 18 and 19)\n"); 
+                printf("\t\tFlag - Modification detection (packets 18 and 19)\n");
         if ((c & ~0xfe) == 0)
-                printf("\t\tFlag - undefined\n"); 
+                printf("\t\tFlag - undefined\n");
         skip(len - 1);
 }
 
@@ -330,14 +327,33 @@ embedded_signature(int len)
 	Signature_Packet(len);
 }
 
-/* 
+public void
+issuer_fingerprint(int len)
+{
+        int v = Getc();
+        len = len-1;
+	printf("\t v%d -", v);
+        if (v == 4) {
+          if (len != 20) {
+            printf(" had %d bytes, should have had 20\n", len);
+            skip(len);
+          } else {
+            fingerprint();
+          }
+        } else {
+          printf(" unknown version\n");
+          skip(len);
+        }
+}
+
+/*
  * Copyright (C) 1998 Kazuhiko Yamamoto
  * All rights reserved.
- * 
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
- * 
+ *
  * 1. Redistributions of source code must retain the above copyright
  *    notice, this list of conditions and the following disclaimer.
  * 2. Redistributions in binary form must reproduce the above copyright
@@ -346,7 +362,7 @@ embedded_signature(int len)
  * 3. Neither the name of the author nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
- * 
+ *
  * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
